summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/klistviewsearchline.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/klistviewsearchline.h')
-rw-r--r--kmymoney2/widgets/klistviewsearchline.h52
1 files changed, 27 insertions, 25 deletions
diff --git a/kmymoney2/widgets/klistviewsearchline.h b/kmymoney2/widgets/klistviewsearchline.h
index 041687e..299f350 100644
--- a/kmymoney2/widgets/klistviewsearchline.h
+++ b/kmymoney2/widgets/klistviewsearchline.h
@@ -21,12 +21,12 @@
#define KLISTVIEWSEARCHLINE_H
#include <klineedit.h>
-#include <qhbox.h>
+#include <tqhbox.h>
#include <kmymoney/export.h>
class KListView;
-class QListViewItem;
-class QToolButton;
+class TQListViewItem;
+class TQToolButton;
/**
* This class makes it easy to add a search line for filtering the items in a
@@ -41,6 +41,7 @@ class QToolButton;
class KMYMONEY_EXPORT KListViewSearchLine : public KLineEdit
{
Q_OBJECT
+ TQ_OBJECT
public:
@@ -51,13 +52,13 @@ public:
* If \a listView is null then the widget will be disabled until a listview
* is set with setListView().
*/
- KListViewSearchLine(QWidget *parent = 0, KListView *listView = 0, const char *name = 0);
+ KListViewSearchLine(TQWidget *tqparent = 0, KListView *listView = 0, const char *name = 0);
/**
* Constructs a KListViewSearchLine without any KListView to filter. The
* KListView object has to be set later with setListView().
*/
- KListViewSearchLine(QWidget *parent, const char *name);
+ KListViewSearchLine(TQWidget *tqparent, const char *name);
/**
* Destroys the KListViewSearchLine.
@@ -77,10 +78,10 @@ public:
*
* @see setSearchColumns
*/
- QValueList<int> searchColumns() const;
+ TQValueList<int> searchColumns() const;
/**
- * If this is true (the default) then the parents of matched items will also
+ * If this is true (the default) then the tqparents of matched items will also
* be shown.
*
* @see setKeepParentsVisible()
@@ -99,7 +100,7 @@ public slots:
* Updates search to only make visible the items that match \a s. If
* \a s is null then the line edit's text will be used.
*/
- virtual void updateSearch(const QString &s = QString::null);
+ virtual void updateSearch(const TQString &s = TQString());
/**
* Make the search case sensitive or case insensitive.
@@ -110,10 +111,10 @@ public slots:
/**
* When a search is active on a list that's organized into a tree view if
* a parent or ancesestor of an item is does not match the search then it
* will be hidden and as such so too will any children that match.
*
- * If this is set to true (the default) then the parents of matching items
+ * If this is set to true (the default) then the tqparents of matching items
* will be shown.
*
* @see keepParentsVisible
@@ -127,7 +128,7 @@ public slots:
*
* @see searchColumns
*/
- void setSearchColumns(const QValueList<int> &columns);
+ void setSearchColumns(const TQValueList<int> &columns);
/**
* Sets the KListView that is filtered by this search line. If \a lv is null
@@ -144,14 +145,14 @@ protected:
* based on the value of caseSensitive(). This can be overridden in
* subclasses to implement more complicated matching schemes.
*/
- virtual bool itemMatches(const QListViewItem *item, const QString &s) const;
+ virtual bool itemMatches(const TQListViewItem *item, const TQString &s) const;
/**
* Re-implemented for internal reasons. API not affected.
*
- * See QLineEdit::mousePressEvent().
+ * See TQLineEdit::mousePressEvent().
*/
- virtual QPopupMenu *createPopupMenu();
+ virtual TQPopupMenu *createPopupMenu();
protected slots:
/**
@@ -167,7 +168,7 @@ protected slots:
*
* @see activateSearch()
*/
- void queueSearch(const QString &search);
+ void queueSearch(const TQString &search);
/**
* When the timer started with queueSearch() expires this slot is called.
@@ -182,20 +183,20 @@ protected slots:
private:
/**
* This is used in case parent items of matching items shouldn't be
* visible. It hides all items that don't match the search string.
*/
void checkItemParentsNotVisible();
/**
* This is used in case parent items of matching items should be visible.
* It makes a recursive call to all children. It returns true if at least
* one item in the subtree with the given root item is visible.
*/
- bool checkItemParentsVisible(QListViewItem *item, QListViewItem *highestHiddenParent = 0);
+ bool checkItemParentsVisible(TQListViewItem *item, TQListViewItem *highestHiddenParent = 0);
private slots:
- void itemAdded(QListViewItem *item) const;
+ void itemAdded(TQListViewItem *item) const;
void listViewDeleted();
void searchColumnsMenuActivated(int);
@@ -210,16 +211,17 @@ private:
*
* @since 3.4
*/
-class KMYMONEY_EXPORT KListViewSearchLineWidget : public QHBox
+class KMYMONEY_EXPORT KListViewSearchLineWidget : public TQHBox
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Creates a KListViewSearchLineWidget for \a listView with \a parent as the
* parent with and \a name.
*/
- KListViewSearchLineWidget(KListView *listView = 0, QWidget *parent = 0,
+ KListViewSearchLineWidget(KListView *listView = 0, TQWidget *tqparent = 0,
const char *name = 0);
/**
@@ -110,10 +111,10 @@ public slots:
/**
* When a search is active on a list that's organized into a tree view if
- * a parent or ancesestor of an item is does not match the search then it
- * will be hidden and as such so too will any children that match.
+ * a tqparent or ancesestor of an item is does not match the search then it
+ * will be hidden and as such so too will any tqchildren that match.
*
@@ -182,20 +183,20 @@ protected slots:
private:
/**
- * This is used in case parent items of matching items shouldn't be
+ * This is used in case tqparent items of matching items shouldn't be
* visible. It hides all items that don't match the search string.
*/
@@ -182,20 +183,20 @@ protected slots:
void checkItemParentsNotVisible();
/**
- * This is used in case parent items of matching items should be visible.
- * It makes a recursive call to all children. It returns true if at least
+ * This is used in case tqparent items of matching items should be visible.
+ * It makes a recursive call to all tqchildren. It returns true if at least
* one item in the subtree with the given root item is visible.
*/
@@ -210,16 +211,17 @@ private:
public:
/**
- * Creates a KListViewSearchLineWidget for \a listView with \a parent as the
- * parent with and \a name.
+ * Creates a KListViewSearchLineWidget for \a listView with \a tqparent as the
+ * tqparent with and \a name.
*/